@@ -1,7 +1,7 @@
 /***************************************************************************
                       codegenerator.cpp  -  description
                              -------------------
-    copyright            : (C) 2007-2020 by Andre Simon
+    copyright            : (C) 2007-2021 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -31,7 +31,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #include <unistd.h>
 #endif
 
-#include <cstdlib> 
+#include <cstdlib>
 #include <cstring>
 #include <fstream>
 #include "version.h"
@@ -76,7 +76,7 @@ CodeGenerator * CodeGenerator::getInstance(OutputType type)
     case SVG:
         generator = new SVGGenerator();
         break;
-    
+
     default:
         break;
     }
@@ -96,7 +96,7 @@ CodeGenerator::CodeGenerator(ansifilter::OutputType type)
      lineNumberWidth ( 5 ),
      lineNumber ( 0 ),
      showLineNumbers ( false ),
-     
+
      numberWrappedLines ( true ), //TODO add option
      numberCurrentLine(false),
      addAnchors(false),
@@ -105,7 +105,7 @@ CodeGenerator::CodeGenerator(ansifilter::OutputType type)
      parseCP437(false),
      parseAsciiBin(false),
      parseAsciiTundra(false),
-     
+
      outputType(type),
      ignoreFormatting(false),
      readAfterEOF(false),
@@ -123,8 +123,6 @@ CodeGenerator::CodeGenerator(ansifilter::OutputType type)
      lineWrapLen(0)
 {
     elementStyle.setFgColour(rgb2html(workingPalette[0]));
-    // first style: default coloring
-    //documentStyles.push_back(StyleInfo ( rgb2html(workingPalette[0]).substr(1), "", false,  false, false, false, false));
 }
 
 CodeGenerator::~CodeGenerator()
@@ -147,15 +145,15 @@ void CodeGenerator::setWrapNoNumbers(bool flag)
 }
 
 void CodeGenerator::setParseCodePage437(bool flag){
-    parseCP437 = flag; 
+    parseCP437 = flag;
 }
 
 void CodeGenerator::setParseAsciiBin(bool flag){
-    parseAsciiBin = flag; 
+    parseAsciiBin = flag;
 }
 
 void CodeGenerator::setParseAsciiTundra(bool flag){
-    parseAsciiTundra = flag; 
+    parseAsciiTundra = flag;
 }
 
 void CodeGenerator::setIgnoreClearSeq(bool flag) {
@@ -215,7 +213,7 @@ void CodeGenerator::setPreformatting ( WrapMode lineWrappingStyle,
                                        unsigned int lineLength
                                      )
 {
-    
+
     lineWrapLen = lineLength;
 }
 
@@ -380,7 +378,7 @@ bool CodeGenerator::printDynamicStyleFile ( const string &outPath )
 }
 
 /*
-  
+
  ESC[nL       Inserts n blank lines at cursor line.   (NANSI)
  ESC[nM       Deletes n lines including cursor line.  (NANSI)
  ESC[n@       Inserts n blank chars at cursor.        (NANSI)
@@ -389,19 +387,19 @@ bool CodeGenerator::printDynamicStyleFile ( const string &outPath )
  */
 
 bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t end)
-{  
+{
     if (line.empty() || begin==end) { // fix empty grep --color ending sequence
       elementStyle.setReset(true);
       return true;
     }
-  
+
     int ansiCode=0;
     int colorCode=0;
     unsigned char colorValues[3]= {0};
 
     string codes=line.substr(begin, end-begin);
     vector<string> codeVector = StringTools::splitString(codes, ';');
-    
+
     vector<string>::iterator itVectorData = codeVector.begin();
     while( itVectorData != codeVector.end()) {
         StringTools::str2num<int>(ansiCode, *(itVectorData), std::dec);
@@ -410,7 +408,7 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
         switch (ansiCode) {
         case 0:
             elementStyle.setReset(true);
-            break;   
+            break;
         case 1:
             elementStyle.setBold(true);
             elementStyle.setFgColour(rgb2html(workingPalette[8]));
@@ -468,12 +466,12 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
         case 35:
         case 36:
         case 37:
-            if (elementStyle.isBold()){              
+            if (elementStyle.isBold()){
               elementStyle.setFgColour(rgb2html(workingPalette[ansiCode-30+8]));
             } else
               elementStyle.setFgColour(rgb2html(workingPalette[ansiCode-30]));
             break;
-            
+
         case 38: // xterm 256 foreground color mode \033[38;5;<color>
 
             itVectorData++;
@@ -487,22 +485,22 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
                 xterm2rgb((unsigned char)colorCode, colorValues);
                 elementStyle.setFgColour(rgb2html(colorValues));
             } else if (*(itVectorData)=="2") {
-                
+
                 itVectorData++;
                 if (itVectorData == codeVector.end()) break;
                 StringTools::str2num<int>(colorCode, *(itVectorData), std::dec);
                 colorValues[0] = colorCode & 0xff;
                 itVectorData++;
-                
+
                 if (itVectorData == codeVector.end()) break;
                 StringTools::str2num<int>(colorCode, *(itVectorData), std::dec);
                 colorValues[1] = colorCode & 0xff;
-                
+
                 itVectorData++;
                 if (itVectorData == codeVector.end()) break;
                 StringTools::str2num<int>(colorCode, *(itVectorData), std::dec);
                 colorValues[2] = colorCode & 0xff;
-                
+
                 elementStyle.setFgColour(rgb2html(colorValues));
             }
             break;
@@ -536,22 +534,22 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
                 xterm2rgb((unsigned char)colorCode, colorValues);
                 elementStyle.setBgColour(rgb2html(colorValues));
             } else if (*(itVectorData)=="2") {
-                
+
                 itVectorData++;
                 if (itVectorData == codeVector.end()) break;
                 StringTools::str2num<int>(colorCode, *(itVectorData), std::dec);
                 colorValues[0] = colorCode & 0xff;
                 itVectorData++;
-                
+
                 if (itVectorData == codeVector.end()) break;
                 StringTools::str2num<int>(colorCode, *(itVectorData), std::dec);
                 colorValues[1] = colorCode & 0xff;
-                
+
                 itVectorData++;
                 if (itVectorData == codeVector.end()) break;
                 StringTools::str2num<int>(colorCode, *(itVectorData), std::dec);
                 colorValues[2] = colorCode & 0xff;
-                
+
                 elementStyle.setBgColour(rgb2html(colorValues));
             }
 
@@ -572,7 +570,7 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
         case 97:
             elementStyle.setFgColour(rgb2html(workingPalette[ansiCode-90+8]));
             break;
-    
+
         case 100:
         case 101:
         case 102:
@@ -605,32 +603,32 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
 
 
 void CodeGenerator::parseCodePage437Seq(string line, size_t begin, size_t end){
-    
+
   string codes=line.substr(begin, end-begin);
   vector<string> codeVector = StringTools::splitString(codes, ',');
-  
+
   if (line[end]=='H'){
     codeVector = StringTools::splitString(codes, ';');
-    
+
     curX = curY = 0;
     if (codeVector.size()==1) {
       curY = atoi(codeVector[0].c_str());
     } else  if (codeVector.size()==2){
      curY = atoi(codeVector[0].c_str());
-     curX = atoi(codeVector[1].c_str()); 
-    }     
+     curX = atoi(codeVector[1].c_str());
+    }
 
     if (maxY<curY && curY<asciiArtHeight) maxY=curY;
   }
-  
-  if (line[end]=='A'){    
+
+  if (line[end]=='A'){
     if (codeVector.size()==1){
       curY -= atoi(codeVector[0].c_str());
      } else {
       curY--;
     }
   }
-  
+
   if (line[end]=='B'){
     if (codeVector.size()==1){
       curY += atoi(codeVector[0].c_str());
@@ -639,9 +637,9 @@ void CodeGenerator::parseCodePage437Seq(string line, size_t begin, size_t end){
     }
     if (maxY<curY && curY<asciiArtHeight) maxY=curY;
   }
-  
+
   if (line[end]=='C'){
-    
+
     if (codeVector.size()==1){
       curX += atoi(codeVector[0].c_str());
     } else {
@@ -655,31 +653,31 @@ void CodeGenerator::parseCodePage437Seq(string line, size_t begin, size_t end){
       if (maxY<curY && curY<asciiArtHeight) maxY=curY;
     }
   }
-  
+
   if (line[end]=='D'){
     if (codeVector.size()==1){
       curX -= atoi(codeVector[0].c_str());
      } else {
       curX--;
     }
-    if (curX<0) curX=0;    
+    if (curX<0) curX=0;
   }
-  
+
   if (line[end]=='J'){
  //   std::cerr<<"J!!!\n";
     /*
     if (codeVector.size()==1 && codeVector[0]=="2"){
       for (int i=0;i<100*100;i++) *termBuffer[i]->c =0;
-    } 
+    }
     */
   }
-  
+
   if (line[end]=='K'){
   //  std::cerr<<"K!!!\n";
     //    for (int i=curX;i<asciiArtWidth;i++) termBuffer[curY*asciiArtWidth + i]->c =0;
-     
+
   }
-  
+
   if (line[end]=='s'){
     memX = curX;
     memY = curY;
@@ -690,7 +688,7 @@ void CodeGenerator::parseCodePage437Seq(string line, size_t begin, size_t end){
     curY = memY;
     elementStyle=memStyle;
   }
- 
+
 }
 
 void CodeGenerator::insertLineNumber ()
@@ -719,23 +717,23 @@ void CodeGenerator::printTermBuffer() {
                 break;
             }
             elementStyle = termBuffer[x + y* asciiArtWidth].style;
-            
+
             //full block
             if (termBuffer[x + y* asciiArtWidth].c == 0xdb){
                 elementStyle.setBgColour(elementStyle.getFgColour());
             }
-            
+
             if (!elementStyle.isReset()) {
                 *out <<getOpenTag();
             }
-            
+
             *out << maskCP437Character(termBuffer[x + y* asciiArtWidth].c);
-            
+
             if (!elementStyle.isReset()) {
                 *out <<getCloseTag();
             }
         }
-    *out<<newLineTag;  
+    *out<<newLineTag;
   }
   out->flush();
   delete [] termBuffer;
@@ -749,36 +747,36 @@ void CodeGenerator::parseBinFile(){
   int count=0;
   allocateTermBuffer();
   while (in->read (buffer, 2)){
-    
+
     cur = buffer[0]&0xff;
     next = buffer[1]&0xff;
-    
+
     int colBg = (next & 240) >> 4;
     int colFg = (next & 15);
-    
+
     if (colBg > 8)
     {
       colBg -= 8;
     }
-    
+
     elementStyle.setFgColour(rgb2html(workingPalette[colFg]));
     elementStyle.setBgColour(rgb2html(workingPalette[colBg]));
-    
+
     //FIXME:
     elementStyle.setBold(cur >= 0x20 && cur <= 0x7a);
-    
+
     if (curX>=0 && curX<asciiArtWidth && curY>=0 && curY<asciiArtHeight){
       termBuffer[curX + curY*asciiArtWidth].c = cur;
       termBuffer[curX + curY*asciiArtWidth].style = elementStyle;
       curX++;
-    } 
+    }
     if (count % asciiArtWidth == 0 ) {
-      curY++;  
+      curY++;
       if (maxY<curY && curY<asciiArtHeight) maxY=curY;
       curX=0;
     }
-    count+=2; 
-  } 
+    count+=2;
+  }
 }
 
 // the XBIN decoding function is based on AnsiLove:
@@ -789,7 +787,7 @@ void CodeGenerator::parseXBinFile(){
     char palette [48] = {0};
 
     if (in->read(header, 11)){
-      
+
       asciiArtWidth = 0xff & ((header[ 6 ] << 8) + header[ 5 ]);
       asciiArtHeight = 0xff & ((header[ 8 ] << 8) + header[ 7 ]);
       int fontSize = header[ 9 ];
@@ -801,11 +799,11 @@ void CodeGenerator::parseXBinFile(){
       std::cerr<<"XBIN flags:"<<flags<<"\n";
 */
       allocateTermBuffer();
-          
+
       if( (flags & 1) == 1 && in->read(palette, 48)) {
         int loop;
         int index;
-        
+
         //override default palette
         //TODO allow user to override this with a map?
         for (loop = 0; loop < 16; loop++)
@@ -816,25 +814,25 @@ void CodeGenerator::parseXBinFile(){
           workingPalette[loop][2] = palette[index+2] << 2 | palette[index+2] >> 4;
         }
       }
-      
+
       // skip font
       if( (flags & 2) == 2 ) {
-        int numchars = ( flags & 0x10 ? 512 : 256 );      
+        int numchars = ( flags & 0x10 ? 512 : 256 );
         in->seekg ( fontSize * numchars, ios::cur);
       }
-      
+
       // decode image
       if( (flags & 4) == 4) {
         int c=0;
         while( in && curY < asciiArtHeight)
-        { 
+        {
           c = in->get();
           int compression = c & 0xC0;
           int cnt = ( c & 0x3F ) + 1;
-          
+
           int cur = -1;
           int attr = -1;
-          
+
           while( cnt-- ) {
             // none
             if( compression == 0 ) {
@@ -864,27 +862,27 @@ void CodeGenerator::parseXBinFile(){
                 attr = in->get();
               }
             }
-            
+
             int colBg = (attr & 240) >> 4;
             int colFg = (attr & 15);
-            
+
             if (colBg > 8)
             {
               colBg -= 8;
             }
-            
+
             elementStyle.setFgColour(rgb2html(workingPalette[colFg]));
             elementStyle.setBgColour(rgb2html(workingPalette[colBg]));
-            
+
             //FIXME:
             elementStyle.setBold(cur >= 0x20 && cur <= 0x7a);
-            
+
             if (curX>=0 && curX<asciiArtWidth && curY>=0 && curY<asciiArtHeight){
               termBuffer[curX + curY*asciiArtWidth].c = cur;
               termBuffer[curX + curY*asciiArtWidth].style = elementStyle;
               curX++;
             }
-          
+
             if (curX == asciiArtWidth)
             {
               curX = 0;
@@ -896,7 +894,7 @@ void CodeGenerator::parseXBinFile(){
     } else {
       //flat BIN
       parseBinFile();
-    } 
+    }
   }
 }
 
@@ -908,41 +906,41 @@ void CodeGenerator::parseTundraFile(){
     if ( in->read (buffer, 9) ) {
         isTundra = string(buffer)=="\x18TUNDRA24";
     }
-    
+
     if (!isTundra) {
         std::cerr<<"not a Tundra file\n";
         return;
     }
-    
+
     asciiArtWidth = 80;
 
     allocateTermBuffer();
-  
+
     int fg_red=0, fg_green=0, fg_blue=0;
     int bg_red=0, bg_green=0, bg_blue=0;
     while (in->read (buffer, 1)){
-    
+
         if (curX >= asciiArtWidth){
             curX = 0;
             curY ++;
         }
-        
+
         int cur = buffer[0]&0xff;
-        
+
         if (cur==1) {
-            if (!in->read (buffer, 8)) goto GENTLE_EXIT; 
-            
+            if (!in->read (buffer, 8)) goto GENTLE_EXIT;
+
             curY = ((buffer[0] << 24)& 0xff) + ((buffer[1] << 16)& 0xff) + ((buffer[2] << 8)& 0xff) + (buffer[3]& 0xff);
             curX = ((buffer[4] << 24)& 0xff) + ((buffer[5] << 16)& 0xff) + ((buffer[6] << 8)& 0xff) + (buffer[7]& 0xff);
-        }    
-    
+        }
+
         if (cur == 2)
         {
             if (!in->read (buffer, 5) ) goto GENTLE_EXIT;
-            
+
             fg_red=buffer[2];
             fg_green=buffer[3];
-            fg_blue=buffer[4]; 
+            fg_blue=buffer[4];
             cur= buffer[0];
         }
 
@@ -954,19 +952,19 @@ void CodeGenerator::parseTundraFile(){
             bg_blue=buffer[4];
             cur= buffer[0];
         }
-        
+
         if (cur==6)
         {
             if (!in->read (buffer, 10) ) goto GENTLE_EXIT;
-        
+
             fg_red=buffer[2];
             fg_green=buffer[3];
             fg_blue=buffer[4];
-            
+
             bg_red=buffer[6];
             bg_green=buffer[7];
             bg_blue=buffer[8];
-            
+
             cur = buffer[0];
         }
 
@@ -974,25 +972,23 @@ void CodeGenerator::parseTundraFile(){
         {
             elementStyle.setFgColour(rgb2html( fg_red&0xff, fg_green&0xff, fg_blue&0xff));
             elementStyle.setBgColour(rgb2html( bg_red&0xff, bg_green&0xff, bg_blue&0xff ));
-  
+
             termBuffer[curX + curY*asciiArtWidth].style = elementStyle;
 
             termBuffer[curX + curY*asciiArtWidth].c  = cur &0xff;
             curX++;
         }
   }
- 
+
 GENTLE_EXIT:
 
   maxY =  curY<asciiArtHeight ?  curY : asciiArtHeight;
 }
 
-
-
 void CodeGenerator::allocateTermBuffer(){
-  
+
   if (termBuffer) delete [] termBuffer;
-  
+
   termBuffer = new TDChar[asciiArtWidth*asciiArtHeight];
   for (int i=0; i<asciiArtWidth*asciiArtHeight; i++){
     termBuffer[i].c=0;
@@ -1001,7 +997,7 @@ void CodeGenerator::allocateTermBuffer(){
 
 bool CodeGenerator::streamIsXBIN() {
   if (in==&cin) return false;
-  
+
   bool isXBIN = false;
   char head[5] = {0};
   if (in->read (head, sizeof head -1) ) {
@@ -1015,10 +1011,10 @@ bool CodeGenerator::streamIsXBIN() {
 
 bool CodeGenerator::streamIsTundra() {
   if (in==&cin) return false;
-    
+
   bool isTND = false;
   char head[10] = {0};
-  
+
   if (in->read (head, sizeof head -1) ) {
     isTND = string(head)=="\x18TUNDRA24";
   }
@@ -1032,31 +1028,31 @@ void CodeGenerator::processInput()
 {
   int cur=0;
   int next=0;
-  
+
   if (parseCP437 || parseAsciiBin || parseAsciiTundra){
     elementStyle.setReset(false);
   }
 
   // deal with BIN/XBIN without file watching, reformatting and line numbering distractions
   if (parseAsciiBin){
-    
+
     if (streamIsXBIN())
       parseXBinFile();
     else
       parseBinFile();
 
     printTermBuffer();
-    return; 
+    return;
   }
 
   if (parseAsciiTundra && streamIsTundra()){
     parseTundraFile();
 
     printTermBuffer();
-    return; 
+    return;
   }
 
-  
+
   // handle normal text files
   if (readAfterEOF && in!=&cin) {
     in->seekg (0, ios::end);
@@ -1069,17 +1065,17 @@ void CodeGenerator::processInput()
       in->seekg (0, ios::beg); // output complete file
     }
   }
- 
+
   if (streamIsXBIN()) {
    *out<<"Please apply --art-bin option for XBIN files.\n";
-   return; 
+   return;
   }
- 
+
   if (streamIsTundra()) {
    *out<<"Please apply --art-tundra option for TND files.\n";
-   return; 
+   return;
   }
-  
+
   string line;
   size_t i=0;
   size_t plainTxtCnt=0;
@@ -1089,18 +1085,20 @@ void CodeGenerator::processInput()
 
   bool omitNewLine=false;
   lineNumber=0;
-    
+
   if (parseCP437){
     allocateTermBuffer();
   }
 
   while (true) {
-    
+
     bool eof=false;
-    
+
     eof=!getline(*in, line);
+
     if( !omitNewLine )
-    ++lineNumber;
+        ++lineNumber;
+
     numberCurrentLine = true;
 
     if (eof) {
@@ -1114,24 +1112,28 @@ void CodeGenerator::processInput()
         sleep(1);
         #endif
       } else {
-        if (!parseCP437 && !omitTrailingCR) printNewLine(outputType!=TEXT);
+        if (!parseCP437 && !omitTrailingCR)
+            printNewLine(outputType!=TEXT);
         break;
       }
     } else {
-        
-      if (!omitNewLine && !parseCP437 && lineNumber>1) printNewLine();  
-     
-      if (!omitNewLine ) insertLineNumber();
+
+      if (!omitNewLine && !parseCP437 && lineNumber>1)
+          printNewLine();
+
+      if (!omitNewLine )
+          insertLineNumber();
+
       omitNewLine = false;
-      
+
       i=0;
       plainTxtCnt=0;
       size_t seqEnd=string::npos;
-      
+
       while (i <line.length() ) {
         // CSI ?
         cur = line[i]&0xff;
-        
+
         if (parseCP437){
 
           if (cur==0x1b && line.length() - i > 2){
@@ -1140,41 +1142,42 @@ void CodeGenerator::processInput()
               i+=2;
               seqEnd = i;
               //find sequence end
-              while (   seqEnd<line.length() 
+              while (   seqEnd<line.length()
                 && (line[seqEnd]<0x40 || line[seqEnd]>0x7e )) {
                 ++seqEnd;
                 }
-                
-                if ( line[seqEnd]=='m' ) {  
+
+                if ( line[seqEnd]=='m' ) {
                   parseSGRParameters(line, i, seqEnd);
                 } else {
-                  parseCodePage437Seq(line, i, seqEnd);  
+                  parseCodePage437Seq(line, i, seqEnd);
                 }
                 i=seqEnd+1;
-            } else {
+            }
+            else {
                 ++i;
             }
           } else  if (cur==0x1a && line.length() - i > 6){
             // skip SAUCE info section
             while (line[i]==0x1a || !line[i]) ++i;
             if (line.substr(i, 5)=="SAUCE"){
-              break; 
+              break;
             }
           } else {
             if (curX>=0 && curX<asciiArtWidth && curY>=0 && curY<asciiArtHeight){
               termBuffer[curX + curY*asciiArtWidth].c = line[i];
               termBuffer[curX + curY*asciiArtWidth].style = elementStyle;
               curX++;
-            } 
-            
+            }
+
             if (curX==asciiArtWidth || line[i]=='\r' ) {
-              curY++;  
+              curY++;
               if (maxY<curY && curY<asciiArtHeight) maxY=curY;
               curX=0;
               if (line[i]=='\r') i=line.length();
             }
             ++i;
-          }  
+          }
         } else {
 
           if ( (cur&0xff)==0x0d && i<line.length()-1) {
@@ -1186,17 +1189,17 @@ void CodeGenerator::processInput()
             // wrap line
           if (lineWrapLen && plainTxtCnt && plainTxtCnt % lineWrapLen==0) {
               ++lineNumber;
-              printNewLine(); 
+              printNewLine();
               insertLineNumber();
               plainTxtCnt=0;
            }
 
-          if ( line.length() - i > 2 && (line[i+1]&0xff)==0x08) i++;  
+          if ( line.length() - i > 2 && (line[i+1]&0xff)==0x08) i++;
           if ( cur==0x07) {
               ++lineNumber;
-              printNewLine();  
+              printNewLine();
               insertLineNumber();
-        }  
+        }
 
           if ( cur==0x1b || (!ignCSISeq && ( cur==0x9b || cur==0xc2)) ) {
 
@@ -1224,25 +1227,44 @@ void CodeGenerator::processInput()
                       i+=2;
                 }
               }
-              
+
+            // https://iterm2.com/documentation-escape-codes.html
+            if (next==0x5d) {
+
+                if (line[i+2]=='8') {
+
+                    size_t uriBegin = line.find(';', i+4);
+                    seqEnd = line.find("\x1b]8;;\x07", i);
+                    size_t uriDelim = line.find(0x07, uriBegin+1);
+
+                    if (uriBegin != string::npos && seqEnd != string::npos){
+                        string uri = line.substr(uriBegin+1, uriDelim - uriBegin - 1 );
+                        string txt = line.substr(uriDelim+1, seqEnd - uriDelim - 1);
+                        lineBuf << getHyperlink(uri, txt);
+                        i=seqEnd+4;
+                    }
+                }
+                ++i;
+            }
+
               if (i<line.size()) ++i;
-              
+
               if (line[i-1]==0x5b || (line[i-1]&0xff)==0x9b){
                 seqEnd=i;
                 //find sequence end
-                while (   seqEnd<line.length() 
+                while (   seqEnd<line.length()
                   && (line[seqEnd]<0x40 || line[seqEnd]>0x7e )) {
                     ++seqEnd;
                   }
-                  
+
                   if (   line[seqEnd]=='m' && !ignoreFormatting ) {
                     if (!elementStyle.isReset()) {
-                      lineBuf <<getCloseTag();
+                      lineBuf << getCloseTag();
                       tagOpen=false;
                     }
                     parseSGRParameters(line, i, seqEnd);
                     if (!elementStyle.isReset()) {
-                      lineBuf <<getOpenTag();
+                      lineBuf << getOpenTag();
                       tagOpen=true;
                     }
                   }
@@ -1250,7 +1272,7 @@ void CodeGenerator::processInput()
                   // fix K sequences (iterm2/grep)
                   isKSeq =  line[seqEnd]=='K' && !ignClearSeq ;
                   isGrepOutput = isKSeq && isascii(line[seqEnd+1]) && line[seqEnd+1] !=13 && line[seqEnd+1] != 27;
-                  
+
                   if (   line[seqEnd]=='s' || line[seqEnd]=='u'
                     || (isKSeq && !isGrepOutput) ){
                       i=line.length()+1;
@@ -1270,20 +1292,20 @@ void CodeGenerator::processInput()
                 {
                   seqEnd=i;
                   //find string end
-                  while ( seqEnd<line.length() 
-                      && (line[seqEnd]&0xff)!=0x9e 
-                      && line[seqEnd]!=0x07 
+                  while ( seqEnd<line.length()
+                      && (line[seqEnd]&0xff)!=0x9e
+                      && line[seqEnd]!=0x07
                       && (line[seqEnd]&0xff)!=0x3b ) {
                         ++seqEnd;
                     }
-                    
+
                     if (line[seqEnd+1]=='A')
                         seqEnd++;
-                 
+
                     i=seqEnd+1;
-                } else if (cur==0x1b && ( 
+                } else if (cur==0x1b && (
                    next==0x37 || next==0x38
-                    
+
                 ) ) // DECSC seq
                 {
                     if (line[seqEnd+1]==0x1b)
@@ -1319,11 +1341,11 @@ void CodeGenerator::processInput()
       }
     }
   } // while (true)
-  
+
   if (tagOpen) {
     *out <<getCloseTag();
   }
-  
+
   if (parseCP437){
     printTermBuffer();
   }
@@ -1402,7 +1424,7 @@ unsigned char CodeGenerator::defaultPalette[16][3] = {
     { 0xFF, 0x00, 0xFF }, // 13 ColorBrightMagenta
     { 0x00, 0xFF, 0xFF }, // 14 ColorBrightCyan
     { 0xFF, 0xFF, 0xFF }  // 15 ColorBrightWhite
-}; 
+};
 
 unsigned char CodeGenerator::workingPalette[16][3] = {
     { 0x00, 0x00, 0x00 }, // 0 ColorBlack
@@ -1421,24 +1443,24 @@ unsigned char CodeGenerator::workingPalette[16][3] = {
     { 0xFF, 0x00, 0xFF }, // 13 ColorBrightMagenta
     { 0x00, 0xFF, 0xFF }, // 14 ColorBrightCyan
     { 0xFF, 0xFF, 0xFF }  // 15 ColorBrightWhite
-}; 
+};
 
 bool CodeGenerator::setColorMap(const string& mapPath){
-  
+
   //restore default colors
   if (mapPath.length()==0){
    memcpy(workingPalette, defaultPalette, sizeof defaultPalette);
    return true;
   }
-  
+
   ifstream mapFile ( mapPath.c_str() );
   if ( mapFile ) {
 
       string line;
-      
+
       unsigned int idx=0;
       char sep='\0';
-          
+
       string colorCode;
       while ( getline ( mapFile, line ) ) {
         stringstream s(line);
@@ -1450,10 +1472,10 @@ bool CodeGenerator::setColorMap(const string& mapPath){
         if (sep!='=') return false;
 
         s>>colorCode;
-        if (colorCode.size()>=7 && colorCode[0]=='#' ) {  
+        if (colorCode.size()>=7 && colorCode[0]=='#' ) {
           workingPalette[idx][0] = (char)std::strtol(colorCode.substr ( 1, 2 ).c_str(), NULL, 16);
           workingPalette[idx][1] = (char)std::strtol(colorCode.substr ( 3, 2 ).c_str(), NULL, 16);
-          workingPalette[idx][2] = (char)std::strtol(colorCode.substr ( 5, 2 ).c_str(), NULL, 16);  
+          workingPalette[idx][2] = (char)std::strtol(colorCode.substr ( 5, 2 ).c_str(), NULL, 16);
         } else {
           return false;
         }
@@ -1461,7 +1483,7 @@ bool CodeGenerator::setColorMap(const string& mapPath){
       mapFile.close();
   } else {
       return false;
-  } 
+  }
   return true;
 }
 
